searchData={"items":[{"type":"module","title":"Routes","doc":"Routes makes your Phoenix routes available in JavaScript.","ref":"Routes.html"},{"type":"function","title":"Routes.after_compile/2","doc":"","ref":"Routes.html#after_compile/2"},{"type":"module","title":"Routes.Collector","doc":"Collects routes from a Phoenix router module.","ref":"Routes.Collector.html"},{"type":"function","title":"Routes.Collector.collect/1","doc":"Collects all routes from the given router module.\nReturns a list of route structs.","ref":"Routes.Collector.html#collect/1"},{"type":"module","title":"Routes.Generator","doc":"Generates JavaScript code with TypeScript definitions for route handling.","ref":"Routes.Generator.html"},{"type":"function","title":"Routes.Generator.generate_javascript/1","doc":"Generates JavaScript code from transformed routes.","ref":"Routes.Generator.html#generate_javascript/1"},{"type":"function","title":"Routes.Generator.generate_typescript_declarations/1","doc":"Generates TypeScript declaration file.","ref":"Routes.Generator.html#generate_typescript_declarations/1"},{"type":"function","title":"Routes.Generator.write_javascript/2","doc":"Writes JavaScript file.","ref":"Routes.Generator.html#write_javascript/2"},{"type":"function","title":"Routes.Generator.write_javascript_with_types/2","doc":"Writes both JavaScript and TypeScript declaration files.","ref":"Routes.Generator.html#write_javascript_with_types/2"},{"type":"module","title":"Routes.Processor","doc":"Processes routes from a module and generates the corresponding JavaScript/TypeScript files.","ref":"Routes.Processor.html"},{"type":"function","title":"Routes.Processor.process_routes/1","doc":"Processes routes from the given module and generates JavaScript/TypeScript files.\n\nReturns `{:ok, routes}` on success or `{:error, reason}` on failure.","ref":"Routes.Processor.html#process_routes/1"},{"type":"function","title":"Examples - Routes.Processor.process_routes/1","doc":"iex> Routes.Processor.process_routes(MyAppWeb.Router)\n    {:ok, [%{path: \"/\", name: \"root\"}, %{path: \"/users\", name: \"users\"}]}","ref":"Routes.Processor.html#process_routes/1-examples"},{"type":"module","title":"Routes.Transformer","doc":"Transforms Phoenix route maps into simplified route structures.\n\nProvides functionality to convert complex Phoenix route maps into a more\nnormalized format that is easier to work with.","ref":"Routes.Transformer.html"},{"type":"function","title":"Routes.Transformer.transform/1","doc":"Transforms a Phoenix route map into a simplified route structure.\n\nTakes a route map containing the path, plug options, HTTP verb and plug module,\nand converts it into a transformed route with normalized fields.\n\nReturns `nil` if the input is invalid or cannot be transformed.","ref":"Routes.Transformer.html#transform/1"},{"type":"type","title":"Routes.Transformer.route_map/0","doc":"","ref":"Routes.Transformer.html#t:route_map/0"},{"type":"type","title":"Routes.Transformer.transformed_route/0","doc":"","ref":"Routes.Transformer.html#t:transformed_route/0"},{"type":"module","title":"Routes.Watcher","doc":"A GenServer that watches for changes to router files and regenerates routes.\n\nThis module provides functionality to:\n- Watch for file system changes in the current working directory\n- Detect modifications to router.ex files\n- Automatically regenerate routes when router files change","ref":"Routes.Watcher.html"},{"type":"function","title":"Routes.Watcher.child_spec/1","doc":"Child spec for supervision tree.","ref":"Routes.Watcher.html#child_spec/1"},{"type":"function","title":"Routes.Watcher.handle_info/2","doc":"Handles file system events, specifically looking for router.ex file modifications.","ref":"Routes.Watcher.html#handle_info/2"},{"type":"function","title":"Routes.Watcher.init/1","doc":"Initializes the watcher by starting a FileSystem process and subscribing to events.","ref":"Routes.Watcher.html#init/1"},{"type":"function","title":"Routes.Watcher.start_link/1","doc":"Starts the watcher process.","ref":"Routes.Watcher.html#start_link/1"},{"type":"function","title":"Options - Routes.Watcher.start_link/1","doc":"Accepts GenServer options. The process will be registered under the module name.","ref":"Routes.Watcher.html#start_link/1-options"},{"type":"extras","title":"Routes","doc":"# Routes\n\nRoutes is an Elixir library that automatically generates JavaScript and TypeScript route helpers directly from your Phoenix router. It provides type-safe route handling in your frontend code, ensuring that your client-side routing stays in sync with your Phoenix routes.\n\nBy integrating Routes into your application, you can effortlessly access your Phoenix routes within your JavaScript or TypeScript codebase, allowing for seamless and type-safe navigation and API calls.","ref":"readme.html"},{"type":"extras","title":"Table of Contents - Routes","doc":"- [Features](#features)\n- [Installation](#installation)\n- [Configuration](#configuration)\n- [Usage](#usage)\n  - [JavaScript and TypeScript](#javascript-and-typescript)\n  - [Inertia.js Integration](#inertiajs-integration)\n  - [Type Safety](#type-safety)\n- [API Reference](#api-reference)\n- [Development](#development)\n- [Contributing](#contributing)\n- [License](#license)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Features - Routes","doc":"- 🔄 **Automatic route generation**: Generates route helpers directly from your Phoenix router.\n- 📝 **TypeScript declarations**: Provides TypeScript definitions for type-safe routing.\n- 🔍 **Live reloading**: Automatically regenerates routes during development when your router changes.\n- 🎯 **Path parameters and query strings**: Supports dynamic path parameters and query string handling.\n- 🚦 **HTTP method access**: Access the HTTP methods associated with your routes.\n- 💪 **Type-safe parameter validation**: Ensures that required parameters are provided and correctly typed.","ref":"readme.html#features"},{"type":"extras","title":"Installation - Routes","doc":"Add `routes` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:routes, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Routes","doc":"1. **Add Routes to your Phoenix Router**:\n\n   In your router file (e.g., `lib/your_app_web/router.ex`), add `use Routes`:\n\n   ```elixir\n   defmodule YourAppWeb.Router do\n     use Phoenix.Router\n     use Routes  # Add this line\n\n     # Your routes...\n   end\n   ```\n\n2. **Configure Routes in `config/config.exs`**:\n\n   Specify your router module and optional settings:\n\n   ```elixir\n   config :routes,\n     router: YourAppWeb.Router,\n     typescript: true,         # Enable TypeScript output, defaults to false\n     routes_path: \"assets/js/routes\"     # Optional, defaults to \"assets/js\"\n   ```\n\n3. **[Optional] Enable live reloading of routes**:\n\n   To automatically regenerate routes when your router file changes during development, add the `Routes.Watcher` to your application's supervision tree in `lib/your_app/application.ex`:\n\n   ```elixir\n   def start(_type, _args) do\n     children = [\n       # ... other children\n     ]\n\n     # Add the Routes.Watcher in development environment\n     children = if Mix.env() == :dev do\n       children ++ [{Routes.Watcher, []}]\n     else\n       children\n     end\n\n     opts = [strategy: :one_for_one, name: YourApp.Supervisor]\n     Supervisor.start_link(children, opts)\n   end\n   ```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Routes","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"JavaScript and TypeScript - Routes","doc":"Once configured, Routes will generate two files in your configured `routes_path`:\n\n- `routes.js`: The JavaScript route helper implementation.\n- `routes.d.ts`: TypeScript type definitions for full type safety.\n\nYou can import and use Routes in your JavaScript or TypeScript code as follows:\n\n```typescript\n// Import Routes\nimport Routes from './routes';\n\n// Generate a URL with parameters\nconst url = Routes.path('user.show', { id: 123 });\n// => \"/users/123\"\n\n// Add query parameters\nconst searchUrl = Routes.path('user.index', {\n  _query: { search: 'john', filter: 'active' }\n});\n// => \"/users?search=john&filter=active\"\n\n// Get the HTTP method for a route\nconst method = Routes.method('user.create');\n// => \"POST\"\n\n// Check if a route exists\nif (Routes.hasRoute('user.edit')) {\n  // Route exists, proceed...\n}\n```\n\n#### Replacing Path Parameters Directly\n\nYou can also use the `replaceParams` function to replace parameters in a given path:\n\n```typescript\nconst customUrl = Routes.replaceParams('/posts/:postId/comments/:commentId', {\n  postId: 42,\n  commentId: 10,\n  _query: { highlight: true }\n});\n// => \"/posts/42/comments/10?highlight=true\"\n```","ref":"readme.html#javascript-and-typescript"},{"type":"extras","title":"Inertia.js Integration - Routes","doc":"If you're using [Inertia.js](https://inertiajs.com/), you can create a type-safe `Link` component that integrates seamlessly with Routes:\n\n```typescript\n// components/Link.tsx\nimport { Link as InertiaLink, InertiaLinkProps } from \"@inertiajs/react\";\nimport React from \"react\";\nimport type { PathParamsWithQuery, RoutePath } from \"./routes\";\nimport Routes from \"./routes\";\n\ntype LinkProps  = Omit  & {\n  to: T;\n  params?: PathParamsWithQuery ;\n  children: React.ReactNode;\n};\n\nexport const Link =  ({\n  to,\n  params,\n  children,\n  ...props\n}: LinkProps ) => {\n  const href = Routes.replaceParams(to, params);\n\n  return (\n     \n      {children}\n     \n  );\n};\n```\n\n**Usage of the Inertia Link component:**\n\n```typescript\nimport { Link } from \"./components/Link\";\n\n// In your component\n \n  View Profile\n \n```","ref":"readme.html#inertia-js-integration"},{"type":"extras","title":"Type Safety - Routes","doc":"Routes provides full TypeScript support with:\n\n- **Route name autocompletion**: Get suggestions for route names as you type.\n- **Parameter validation**: TypeScript will enforce that you provide all required parameters with correct types.\n- **HTTP method types**: Methods like `Routes.method` return typed HTTP methods.\n- **Query parameter support**: Supports type-checked query parameters.\n\n**Example:**\n\n```typescript\n// Correct usage\nconst url = Routes.path('user.show', { id: 123 });\n\n// TypeScript Error: Missing required 'id' parameter\nconst url = Routes.path('user.show');\n\n// TypeScript Error: Route 'user.nonexistent' does not exist\nconst url = Routes.path('user.nonexistent');\n```","ref":"readme.html#type-safety"},{"type":"extras","title":"API Reference - Routes","doc":"### `Routes.path(name, params?)`\n\nGenerates a path (URL) for the given route name with optional parameters.\n\n- **name**: The name of the route (string).\n- **params**: An object containing route parameters and an optional `_query` object for query parameters.\n\n**Example:**\n\n```typescript\nconst url = Routes.path('post.show', { id: 42 });\n// => \"/posts/42\"\n\nconst urlWithQuery = Routes.path('post.index', {\n  _query: { page: 2, sort: 'desc' }\n});\n// => \"/posts?page=2&sort=desc\"\n```\n\n### `Routes.route(name, params?)`\n\nAlias for `Routes.path`.\n\n### `Routes.method(name)`\n\nReturns the HTTP method associated with the given route name.\n\n- **name**: The name of the route (string).\n\n**Example:**\n\n```typescript\nconst method = Routes.method('post.create');\n// => \"POST\"\n```\n\n### `Routes.hasRoute(name)`\n\nChecks if a route with the given name exists.\n\n- **name**: The name of the route (string).\n\n**Example:**\n\n```typescript\nif (Routes.hasRoute('post.edit')) {\n  // Route exists\n} else {\n  // Route does not exist\n}\n```\n\n### `Routes.replaceParams(path, params?)`\n\nReplaces the path parameters in the given path string with the provided values.\n\n- **path**: The path string containing parameters (e.g., `\"/users/:id\"`).\n- **params**: An object containing parameter values and an optional `_query` object.\n\n**Example:**\n\n```typescript\nconst url = Routes.replaceParams('/users/:id', { id: '123' });\n// => \"/users/123\"\n```","ref":"readme.html#api-reference"},{"type":"extras","title":"Development - Routes","doc":"Routes automatically watches for changes in your Phoenix router file during development and regenerates the route helpers accordingly. This ensures that your frontend code stays up-to-date with your backend routes without manual intervention.\n\nTo enable live reloading, make sure you've added the `Routes.Watcher` to your application's supervision tree as described in the [Configuration](#configuration) section.","ref":"readme.html#development"},{"type":"extras","title":"Contributing - Routes","doc":"We welcome contributions to Routes! To contribute:\n\n1. **Fork the repository** on GitHub.\n2. **Create a new branch** for your feature or bugfix.\n   ```bash\n   git checkout -b my-new-feature\n   ```\n3. **Commit your changes** with clear commit messages.\n   ```bash\n   git commit -am 'Add new feature'\n   ```\n4. **Push to your branch** on GitHub.\n   ```bash\n   git push origin my-new-feature\n   ```\n5. **Create a Pull Request** explaining your changes.\n\nPlease make sure to write tests for your changes and follow the existing code style.","ref":"readme.html#contributing"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}